# Instructions 

### This is our test project. 
### Please install this package
'''
pip install functions_by_olgabotnari
'''

### You can also install older packages
'''
pip install functions-by-olgabotnari==VERSION_NUMBER
'''
